@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1316.2.1 2022/01/08 17:42:15 bket Exp $
+# $OpenBSD: Quirks.pm,v 1.1353 2021/12/05 19:58:12 jca Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -496,6 +496,204 @@ my $stem_extensions = {
 	'py-websocket-client' => 'py3-websocket-client',
 	'libmesode' => 'libstrophe',
 	'py-stem' => 'py3-stem',
+# 7.1	    
+	'py-jsonschema' => 'py3-jsonschema',
+	'py-CherryPy' => 'py3-CherryPy',
+	'py-IP' => 'py3-IP',
+	'py-PySMT' => 'py3-PySMT',
+	'py-aes' => 'py3-aes',
+	'py-affine' => 'py3-affine',
+	'py-beaker' => 'py3-beaker',
+	'py-betamax' => 'py3-betamax',
+	'py-bleach' => 'py3-bleach',
+	'py-bottle' => 'py3-bottle',
+	'py-cached-property' => 'py3-cached-property',
+	'py-cheroot' => 'py3-cheroot',
+	'py-cookies' => 'py3-cookies',
+	'py-country' => 'py3-country',
+	'py-coveralls' => 'py3-coveralls',
+	'py-curl' => 'py3-curl',
+	'py-eapi' => 'py3-eapi',
+	'py-fasteners' => 'py3-fasteners',
+	'py-feedgenerator' => 'py3-feedgenerator',
+	'py-fields' => 'py3-fields',
+	'py-formencode' => 'py3-formencode',
+	'py-ftpdlib' => 'py3-ftpdlib',
+	'py-graphviz' => 'py3-graphviz',
+	'py-html5lib' => 'py3-html5lib',
+	'py-httplib2' => 'py3-httplib2',
+	'py-icalendar' => 'py3-icalendar',
+	'py-jinja2' => 'py3-jinja2',
+	'py-mako' => 'py3-mako',
+	'py-mistune' => 'py3-mistune',
+	'py-mpmath' => 'py3-mpmath',
+	'py-netaddr' => 'py3-netaddr',
+	'py-netifaces' => 'py3-netifaces',
+	'py-num2words' => 'py3-num2words',
+	'py-objgraph' => 'py3-objgraph',
+	'py-paho-mqtt' => 'py3-paho-mqtt',
+	'py-parsedatetime' => 'py3-parsedatetime',
+	'py-path.py' => 'py3-path.py',
+	'py-pcapy' => 'py3-pcapy',
+	'py-pf' => 'py3-pf',
+	'py-pgpdump' => 'py3-pgpdump',
+	'py-polib' => 'py3-polib',
+	'py-portend' => 'py3-portend',
+	'py-potr' => 'py3-potr',
+	'py-prettytable' => 'py3-prettytable',
+	'py-pyaml' => 'py3-pyaml',
+	'py-pykwalify' => 'py3-pykwalify',
+	'py-radix' => 'py3-radix',
+	'py-redis' => 'py3-redis',
+	'py-repoze-lru' => 'py3-repoze-lru',
+	'py-repoze-profile' => 'py3-repoze-profile',
+	'py-repoze-who' => 'py3-repoze-who',
+	'py-requests-aws4auth' => 'py3-requests-aws4auth',
+	'py-requests-futures' => 'py3-requests-futures',
+	'py-requests-mock' => 'py3-requests-mock',
+	'py-requests-toolbelt' => 'py3-requests-toolbelt',
+	'py-rrdtool' => 'py3-rrdtool',
+	'py-ruamel.yaml' => 'py3-ruamel.yaml',
+	'py-scrypt' => 'py3-scrypt',
+	'py-selenium' => 'py3-selenium',
+	'py-simplesoap' => 'py3-simplesoap',
+	'py-soupsieve' => 'py3-soupsieve',
+	'py-spdx' => 'py3-spdx',
+	'py-spdx-lookup' => 'py3-spdx-lookup',
+	'py-tempita' => 'py3-tempita',
+	'py-unidecode' => 'py3-unidecode',
+	'py-uritemplate' => 'py3-uritemplate',
+	'py-vobject' => 'py3-vobject',
+	'py-waitress' => 'py3-waitress',
+	'py-webencodings' => 'py3-webencodings',
+	'py-xmltodict' => 'py3-xmltodict',
+	'py-zc-lockfilezc.lockfile' => 'py3-zc-lockfilezc.lockfile',
+	'py-jaraco-functools' => 'py3-jaraco-functools',
+	'py-logilab-common' => 'py3-logilab-common',
+	'py-memcached' => 'py3-memcached',
+	'py-tempora' => 'py3-tempora',
+	'py-redland' => 'py3-redland',
+	'py-GitPython' => 'py3-GitPython',
+	'py-ICU' => 'py3-ICU',
+	'py-MarkupSafe' => 'py3-MarkupSafe',
+	'py-PEG2' => 'py3-PEG2',
+	'py-PyPDF2' => 'py3-PyPDF2',
+	'py-ana' => 'py3-ana',
+	'py-anytree' => 'py3-anytree',
+	'py-appdirs' => 'py3-appdirs',
+	'py-argcomplete' => 'py3-argcomplete',
+	'py-argh' => 'py3-argh',
+	'py-audio' => 'py3-audio',
+	'py-axolotl-curve25519' => 'py3-axolotl-curve25519',
+	'py-backcall' => 'py3-backcall',
+	'py-biplist' => 'py3-biplist',
+	'py-bitstring' => 'py3-bitstring',
+	'py-blessings' => 'py3-blessings',
+	'py-blist' => 'py3-blist',
+	'py-bsddb3' => 'py3-bsddb3',
+	'py-cairocffi' => 'py3-cairocffi',
+	'py-cffi' => 'py3-cffi',
+	'py-characteristic' => 'py3-characteristic',
+	'py-cheetah' => 'py3-cheetah',
+	'py-clint' => 'py3-clint',
+	'py-colored' => 'py3-colored',
+	'py-configobj' => 'py3-configobj',
+	'py-cooldict' => 'py3-cooldict',
+	'py-cssutils' => 'py3-cssutils',
+	'py-cstruct' => 'py3-cstruct',
+	'py-cymruwhois' => 'py3-cymruwhois',
+	'py-daemonize' => 'py3-daemonize',
+	'py-decorator' => 'py3-decorator',
+	'py-defusedxml' => 'py3-defusedxml',
+	'py-demjson' => 'py3-demjson',
+	'py-dicttoxml' => 'py3-dicttoxml',
+	'py-discid' => 'py3-discid',
+	'py-dispatcher' => 'py3-dispatcher',
+	'py-dnslib' => 'py3-dnslib',
+	'py-docopt' => 'py3-docopt',
+	'py-easyprocess' => 'py3-easyprocess',
+	'py-entrypoints' => 'py3-entrypoints',
+	'py-filebytes' => 'py3-filebytes',
+	'py-filelock' => 'py3-filelock',
+	'py-flaky' => 'py3-flaky',
+	'py-flexmock' => 'py3-flexmock',
+	'py-frozendict' => 'py3-frozendict',
+	'py-gitdb' => 'py3-gitdb',
+	'py-greenlet' => 'py3-greenlet',
+	'py-ipython_genutils' => 'py3-ipython_genutils',
+	'py-iso3166' => 'py3-iso3166',
+	'py-iso639' => 'py3-iso639',
+	'py-isodate' => 'py3-isodate',
+	'py-isort' => 'py3-isort',
+	'py-jellyfish' => 'py3-jellyfish',
+	'py-jmespath' => 'py3-jmespath',
+	'py-magic' => 'py3-magic',
+	'py-markdown' => 'py3-markdown',
+	'py-mccabe' => 'py3-mccabe',
+	'py-minimock' => 'py3-minimock',
+	'py-mox3' => 'py3-mox3',
+	'py-msgpack' => 'py3-msgpack',
+	'py-munch' => 'py3-munch',
+	'py-nose-warnings-filters' => 'py3-nose-warnings-filters',
+	'py-nosexcover' => 'py3-nosexcover',
+	'py-odbc' => 'py3-odbc',
+	'py-olefile' => 'py3-olefile',
+	'py-pandocfilters' => 'py3-pandocfilters',
+	'py-parallel' => 'py3-parallel',
+	'py-pathlib' => 'py3-pathlib',
+	'py-pathspec' => 'py3-pathspec',
+	'py-pbkdf2' => 'py3-pbkdf2',
+	'py-peewee' => 'py3-peewee',
+	'py-phonenumbers' => 'py3-phonenumbers',
+	'py-pickleshare' => 'py3-pickleshare',
+	'py-progress' => 'py3-progress',
+	'py-progressbar' => 'py3-progressbar',
+	'py-pyprof2calltree' => 'py3-pyprof2calltree',
+	'py-pyte' => 'py3-pyte',
+	'py-rencode' => 'py3-rencode',
+	'py-robotframework' => 'py3-robotframework',
+	'py-rfc6555' => 'py3-rfc6555',
+	'py-send2trash' => 'py3-send2trash',
+	'py-setuptools_scm_git_archive' => 'py3-setuptools_scm_git_archive',
+	'py-setuptools_trial' => 'py3-setuptools_trial',
+	'py-sh' => 'py3-sh',
+	'py-simpleeval' => 'py3-simpleeval',
+	'py-simplegeneric' => 'py3-simplegeneric',
+	'py-smmap' => 'py3-smmap',
+	'py-socks' => 'py3-socks',
+	'py-sql' => 'py3-sql',
+	'py-stdnum' => 'py3-stdnum',
+	'py-straight.plugin' => 'py3-straight.plugin',
+	'py-test-expect' => 'py3-test-expect',
+	'py-test-forked' => 'py3-test-forked',
+	'py-test-relaxed' => 'py3-test-relaxed',
+	'py-test-subtesthack' => 'py3-test-subtesthack',
+	'py-testpath' => 'py3-testpath',
+	'py-tld' => 'py3-tld',
+	'py-tox' => 'py3-tox',
+	'py-uv' => 'py3-uv',
+	'py-vcversioner' => 'py3-vcversioner',
+	'py-voluptuous' => 'py3-voluptuous',
+	'py-wrapt' => 'py3-wrapt',
+	'py-wstools' => 'py3-wstools',
+	'py-xcbgen' => 'py3-xcbgen',
+	'py-xlsxwriter' => 'py3-xlsxwriter',
+	'py-yamllint' => 'py3-yamllint',
+	'py-yapf' => 'py3-yapf',
+	'py-sqlalchemy' => 'py3-sqlalchemy',
+	'py-flup' => 'py3-flup',
+	'py-feedparser' => 'py3-feedparser',
+	'apertium-af-nl' => 'apertium-afr-nld',
+	'apertium-ca-it' => 'apertium-cat-ita',
+	'apertium-en-ca' => 'apertium-eng-cat',
+	'apertium-es-ast' => 'apertium-spa-ast',
+	'apertium-es-ca' => 'apertium-spa-cat',
+	'apertium-id-ms' => 'apertium-ind-zlm',
+	'apertium-is-en' => 'apertium-isl-eng',
+	'apertium-is-sv' => 'apertium-isl-swe',
+	'apertium-mk-bg' => 'apertium-mkd-bul',
+	'apertium-mk-en' => 'apertium-mkd-eng',
+	'apertium-pt-ca' => 'apertium-por-cat',
 };
 
 my $obsolete_reason = {};
@@ -1081,7 +1279,7 @@ setup_obsolete_reason(
 	0 => 'lazarus',
 	13 => 'exaile',
 	3 => 'instead-launcher',
-	3 => qr{^(ruby(19|2[0-5])-|ruby-[^0-9])},
+	3 => qr{^(ruby(19|2[0-6])-|ruby-[^0-9])},
 # 6.9
 	3 => 'py-notify',
 	3 => 'glimpse',
@@ -1258,6 +1456,172 @@ setup_obsolete_reason(
 	3 => 'bzr',
 	3 => 'bzr-svn',
 	6 => 'libvstr',
+# 7.1
+	0 => 'cue',
+	31 => 'py-SOAPpy',
+	31 => 'py-ao',
+	31 => 'py-backports-abc',
+	31 => 'py-backports-functools-lru-cache',
+	31 => 'py-backports-lzma',
+	31 => 'py-backports-shutil-get-terminal-size',
+	31 => 'py-backports-ssl-match-hostname',
+	31 => 'py-binplist',
+	31 => 'py-bytecodeassembler',
+	31 => 'py-cddb',
+	31 => 'py-editdist',
+	31 => 'py-efilter',
+	31 => 'py-faulthandler',
+	31 => 'py-fpconst',
+	31 => 'py-functools32',
+	31 => 'py-gdata',
+	31 => 'py-guppy',
+	31 => 'py-hachoir-core',
+	31 => 'py-hachoir-metadata',
+	31 => 'py-hachoir-parser',
+	31 => 'py-jonpy',
+	31 => 'py-jsonrpclib',
+	31 => 'py-lzo',
+	31 => 'py-milter',
+	31 => 'py-monotonic',
+	31 => 'py-mox',
+	31 => 'py-mxDateTime',
+	31 => 'py-pdf',
+	31 => 'py-pyro',
+	31 => 'py-pysha3',
+	31 => 'py-python2-pythondialog',
+	31 => 'py-recaptcha-client',
+	31 => 'py-ruamel.ordereddict',
+	31 => 'py-singledispatch',
+	31 => 'py-storm',
+	31 => 'py-subprocess32',
+	31 => 'py-sybase',
+	31 => 'py-symboltype',
+	31 => 'py-xmlrunner',
+	31 => 'py-xmpppy',
+	31 => 'py-yenc',
+	31 => 'py-zsi',
+	8 => 'tilecache',
+	31 => 'py-configparser',
+	31 => 'py-decoratortools',
+	31 => 'py-paste',
+	31 => 'py-paste-deploy',
+	31 => 'py-paste-script',
+	31 => 'py-selectors2',
+	31 => 'py-wsgiutils',
+	31 => 'py-xml',
+	31 => 'py-backports',
+	3 => 'ORBit2',
+	3 => 'libbonobo',
+	3 => 'libgnome',
+	3 => 'mono-gnome',
+	3 => 'libbonoboui',
+	3 => 'libgnomeui',
+	3 => 'gtetrinet',
+	3 => 'gtetrinet-themes',
+	3 => 'grhino',
+	3 => 'gbrainy',
+	3 => 'gnome-vfs2',
+	3 => 'gnome-mime-data',
+	3 => 'libIDL',
+	3 => 'chemical-mime-data',
+	3 => 'gmfsk',
+	13 => 'gmapcatcher',
+	3 => 'childsplay',
+	6 => 'py-texscythe',
+	6 => 'py3-sqlalchemy-migrate',
+	13 => 'rawdog',
+	13 => 'charm',
+	0 => 'ktsuss',
+	11 => 'apertium-ht-en',
+	7 => 'pear-Auth',
+	7 => 'pear-Auth-HTTP',
+	7 => 'pear-Auth-SASL',
+	7 => 'pear-Cache',
+	7 => 'pear-Config',
+	7 => 'pear-Console-Table',
+	7 => 'pear-Date',
+	7 => 'pear-Date-Holidays',
+	7 => 'pear-Date-Holidays_Australia',
+	7 => 'pear-Date-Holidays_Austria',
+	7 => 'pear-Date-Holidays_Brazil',
+	7 => 'pear-Date-Holidays_Chile',
+	7 => 'pear-Date-Holidays_Croatia',
+	7 => 'pear-Date-Holidays_Czech',
+	7 => 'pear-Date-Holidays_Denmark',
+	7 => 'pear-Date-Holidays_Discordian',
+	7 => 'pear-Date-Holidays_EnglandWales',
+	7 => 'pear-Date-Holidays_Finland',
+	7 => 'pear-Date-Holidays_France',
+	7 => 'pear-Date-Holidays_Germany',
+	7 => 'pear-Date-Holidays_Iceland',
+	7 => 'pear-Date-Holidays_Ireland',
+	7 => 'pear-Date-Holidays_Italy',
+	7 => 'pear-Date-Holidays_Japan',
+	7 => 'pear-Date-Holidays_Netherlands',
+	7 => 'pear-Date-Holidays_Norway',
+	7 => 'pear-Date-Holidays_PHPdotNet',
+	7 => 'pear-Date-Holidays_Portugal',
+	7 => 'pear-Date-Holidays_Romania',
+	7 => 'pear-Date-Holidays_Russia',
+	7 => 'pear-Date-Holidays_SanMarino',
+	7 => 'pear-Date-Holidays_Serbia',
+	7 => 'pear-Date-Holidays_Slovenia',
+	7 => 'pear-Date-Holidays_Spain',
+	7 => 'pear-Date-Holidays_Sweden',
+	7 => 'pear-Date-Holidays_Turkey',
+	7 => 'pear-Date-Holidays_UNO',
+	7 => 'pear-Date-Holidays_USA',
+	7 => 'pear-Date-Holidays_Ukraine',
+	7 => 'pear-Date-Holidays_Venezuela',
+	7 => 'pear-File',
+	7 => 'pear-File-Find',
+	7 => 'pear-HTML-Page2',
+	7 => 'pear-HTML-Select',
+	7 => 'pear-HTML-Template_IT',
+	7 => 'pear-HTTP',
+	7 => 'pear-HTTP-Request',
+	7 => 'pear-HTTP-WebDAV-Server',
+	7 => 'pear-Log',
+	7 => 'pear-MIME-Type',
+	7 => 'pear-Mail',
+	7 => 'pear-Mail-Mime',
+	7 => 'pear-Mail-mimeDecode',
+	7 => 'pear-Net-DNS',
+	7 => 'pear-Net-DNS2',
+	7 => 'pear-Net-IDNA2',
+	7 => 'pear-Net-IMAP',
+	7 => 'pear-Net-IPv4',
+	7 => 'pear-Net-IPv6',
+	7 => 'pear-Net-LDAP',
+	7 => 'pear-Net-LDAP2',
+	7 => 'pear-Net-SMTP',
+	7 => 'pear-Net-Sieve',
+	7 => 'pear-Net-Socket',
+	7 => 'pear-Net-URL',
+	7 => 'pear-Net-URL2',
+	7 => 'pear-Net-URL_Mapper',
+	7 => 'pear-SOAP',
+	7 => 'pear-Services-Weather',
+	7 => 'pear-Services-oEmbed',
+	7 => 'pear-System-Command',
+	7 => 'pear-Validate',
+	7 => 'pear-XML-Parser',
+	7 => 'pear-XML-RSS',
+	7 => 'pear-XML-Serializer',
+	7 => 'pear-XML-Tree',
+	3 => 'luacrypto',
+	13 => 'skytools',
+	13 => 'pgloader',
+	7 => 'php-markdown',
+	7 => 'php-predis',
+	5 => 'virtuoso',
+	3 => 'upobsd',
+	9 => 'waagent',
+	3 => 'slim',
+	3 => 'slim-themes',
+	5 => 'ocaml-biniou',
+	5 => 'ocaml-easy-format',
+	5 => 'libdsm',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
@@ -1286,6 +1650,8 @@ my $obsolete_message = {
 	5 => "outdated and/or no longer required by other ports",
 	6 => "no longer useful",
 	7 => "removed in favor of using the language's package manager",
+	8 => "no longer maintained upstream, consider mapproxy as an alternative",
+	9 => "removed, needs a port maintainer",
 	10 => "has been replaced by opendkim",
 	11 => "no longer packageable",
 	12 => "replace with IMAPSieve, see https://wiki.dovecot.org/HowTo/AntispamWithSieve",
@@ -1300,7 +1666,7 @@ my $obsolete_message = {
 	28 => "consider migrating MCollective agents and filters using tools like Bolt and PuppetDB's Puppet Query Language",
 	29 => "unmaintained port that was blocking other changes in ports",
 	30 => "crashes in many different ways at runtime, does not build with '-fno-common'",
-	31 => "upstream is dead, python2-only, nothing uses it",
+	31 => "python port without 3.x support, no other ports use it",
 	33 => "no longer maintained upstream, website suggests https://cronometer.com until rewrite is done",
 	34 => "upstream is dead, basic functionality does not work, use tcpdump(1) and scapy(1) instead",
 	35 => "upstream is dead, no longer useful, does not support IPv6",
@@ -1329,12 +1695,12 @@ sub is_base_system
 	if (defined $test) {
 		require File::Glob;
 		if (defined File::Glob::bsd_glob($test)) {
-			$state->say("Removing #1 #2", $handle->pkgname,
-			    " (part of base system now)");
+			$state->say("Removing #1 (part of base system now)", 
+			    $pkgname);
 			return 1;
 		} else {
-			$state->say("Not removing #1 #2 #3 #4", $handle->pkgname,
-			 ", ", $test, " not found");
+			$state->say("Not removing #1, #2 not found", 
+			    $pkgname, $test);
 			return 0;
 		}
 	} else {
@@ -1449,7 +1815,7 @@ my $cve = {
 	'lang/ruby/2.6,-main' => 'ruby->2.6,<2.6.2',
 	'mail/dovecot,-server' => 'dovecot-<2.3.10.1',
 	'mail/exim' => 'exim-<4.83',
-	'mail/isync' => 'isync-<1.4.2',
+	'mail/isync' => 'isync-<1.4.4',
 	'mail/mailman' => 'mailman-<2.1.30',
 	'mail/p5-Mail-SpamAssassin' => 'p5-Mail-SpamAssassin-<3.4.4',
 	'mail/roundcubemail' => 'roundcubemail-<1.3.8',
@@ -1490,7 +1856,7 @@ my $cve = {
 	'security/libssh' => 'libssh-<0.9.4',
 	'security/opensc' => 'opensc-<0.20.0',
 	'security/openssl/1.1' => 'openssl-<1.1.1g',
-	'security/polarssl' => 'mbedtls-<2.16.12',
+	'security/polarssl' => 'mbedtls-<2.16.6',
 	'security/sudo' => 'sudo-<1.8.31',
 	'shells/bash' => 'bash-<4.3.27',
 	'sysutils/ansible,-main' => 'ansible-<2.7.1',
